<?php
// $Id: template.php,v 1.3 2009/08/27 00:08:07 mtecknology Exp $

/*
 * Table of Contents
 * 1. Theme Settings
 * 2. PHPTemplate Functions
 *    phptemplate_body_class
 *    phptemplate_breadcrumb
 *    phptemplate_breadcrumb
 *    phptemplate_menu_local_tasks
 *    phptemplate_comment_submitted
 *    phptemplate_node_submitted
 *    phptemplate_secondary_links
 *    phptemplate_links
 *    phptemplate_nice_menu_build
 *    phptemplate_nice_menu
 *    phptemplate_preprocess_page 
 * 3. UbuntuDrupal Functions
 *   3a. UbuntuDrupal Variable Overrides
 *     ubuntudrupal_whichmenu
 *     ubuntudrupal_buildlogo
 *     ubuntudrupal_spacergif
 *     ubuntudrupal_sitename
 *     ubuntudrupal_siteslogan
 *     ubuntudrupal_secondarylinks
 *     ubuntudrupal_rulebar
 *     ubuntudrupal_lfooter
 *   3b. UbuntuDrupal Functional Variables
 *     center()
 *     pagewidth()
 */


/*
 * 1. Theme Settings
 *    Standard method to offer custom settings
 */

if (is_null(theme_get_setting('wrapper_width'))) {
  global $theme_key;

  $defaults = array(
    'wrapper_width' => 960,
    'custom_footer_right' => 'Theme created by the <a href="https://launchpad.net/~ubuntu-drupal-themes">Ubuntu Drupal</a> team.',
  );

  $settings = theme_get_settings($theme_key);

  if (module_exists('node')) {
    foreach (node_get_types() as $type => $name) {
      unset($settings['toggle_node_info_' . $type]);
    }
  }

  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge($defaults, $settings)
  );

  theme_get_setting('', TRUE);
}

/*
 * 2. PHPTemplate Functions
 */

/**
 * hook _body_class
 * Used to apply the correct class to the page
 */
function phptemplate_body_class($left, $right, $header = '', $footer = '', $var_show_blocks) {
 if ($var_show_blocks) {
   if ($left != '' && $right != '') {
     $class = 'sidebars';
   }
   else {
     if ($right == '' && $left == '' && ($header != '' || $footer != '')) {
       $class = 'sidebars';
     }
     if ($left != '') {
       if ($header != '' || $footer != '') {
        $class = 'sidebar-mix';
       }
       else {
        $class = 'sidebar-left';
       }
     }
     if ($right != '') {
        if ($header != '' || $footer != '') {
          $class = 'sidebar-mix';
        }
        else {
         $class = 'sidebar-right';
        }
      }
      if ($right == '' && $left == '' && $header == '' && $footer != '') {
        $class = 'sidebar-footer';
      }
    }
  }

  if (isset($class)) {
    return ' class="'. $class .'"';
  }
}

/**
 * hook _breadcrumb
 * Used to wrap breadcrumb in predefined div
 */
function phptemplate_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
// uncomment the next line to enable current page in the breadcrumb trail
//    $breadcrumb[] = drupal_get_title();
    return '<div class="breadcrumb">'. implode(' > ', $breadcrumb) .'</div>';
  }
}

/**
 * hook _comment_wrapper
 * Used to wrap comments in a predefined div as well as modify output
 */
function phptemplate_comment_wrapper($content, $node) {
  if (!$content || $node->type == 'forum') {
    return '<div id="comments">'. $content .'</div>';
  }
  else {
    return '<div id="comments"><h2 class="comments">'. t('Comments') .'</h2>'. $content .'</div>';
  }
}

/**
 * Build primary links
 */
function phptemplate_menu_local_tasks() {
  return menu_primary_local_tasks();
}

/**
 * Show when the comment was submitted
 */
function phptemplate_comment_submitted($comment) {
  return t('by !username on !datetime',
    array(
      '!username' => theme('username', $comment),
      '!datetime' => format_date($comment->timestamp)
    ));
}

/**
 * Show when the node was submitted
 */
function phptemplate_node_submitted($node) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $node),
      '!datetime' => format_date($node->created),
    ));
}

/**
 * Build the secondary links using custom styles
 */
function phptemplate_secondary_links($links, $attributes = '') {
  $output = '';

  if (count($links) > 0) {
    $output = '<ul'. drupal_attributes($attributes) .'>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = ""; //was = $key;

      // Add first, last and active classes to the list of links to help out themers.
      if ($i == 1) {
        $class .= ''; //was ' first';
      }
      if ($i == $num_links) {
        $class .= '';  //was ' last';
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))) {
        $class .= 'current'; //was ' active';
      }
      if ($class == "") {
        $class = 'plain';
      }
      $output .= '<li'. drupal_attributes(array('class' => $class)) .'>';

      if (isset($link['href'])) {
        // Pass in $link as $options, they share the same keys.
        $output .= l($link['title'], $link['href'], $link);
      }
      else if (!empty($link['title'])) {
        // Some links are actually not links, but we wrap these in <span> for adding title and class attributes
        if (empty($link['html'])) {
          $link['title'] = check_plain($link['title']);
        }
        $span_attributes = '';
        if (isset($link['attributes'])) {
          $span_attributes = drupal_attributes($link['attributes']);
        }
        $output .= '<span'. $span_attributes .'>'. $link['title'] .'</span>';
      }

      $i++;
      $output .= "</li>\n";
    }

    $output .= '</ul>';
  }

  return $output;
}

/**
 * Build the primary links using custom styles
 */
function phptemplate_links($links, $attributes = array('class' => 'links')) {
  $output = '';

  if (count($links) > 0) {
    $output = '<ul'. drupal_attributes($attributes) .'>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = ""; //was = $key;

      // Add first, last and active classes to the list of links to help out themers.
      if ($i == 1) {
        $class .= ''; //was ' first';
      }
      if ($i == $num_links) {
        $class .= '';  //was ' last';
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))) {
        $class .= ''; //was ' active';
      }

      $output .= '<li'. drupal_attributes(array('class' => $class)) .'>';

      if (isset($link['href'])) {
        // Pass in $link as $options, they share the same keys.
        $output .= l($link['title'], $link['href'], $link);
      }
      else if (!empty($link['title'])) {
        // Some links are actually not links, but we wrap these in <span> for adding title and class attributes
        if (empty($link['html'])) {
          $link['title'] = check_plain($link['title']);
        }
        $span_attributes = '';
        if (isset($link['attributes'])) {
          $span_attributes = drupal_attributes($link['attributes']);
        }
        $output .= '<span'. $span_attributes .'>'. $link['title'] .'</span>';
      }

      $i++;
      $output .= "</li>\n";
    }

    $output .= '</ul>';
  }

  return $output;
}

/**
 * Build nice_menu
 */
function phptemplate_nice_menu_build($menu) {
  $output = '';  

  foreach ($menu as $menu_item) {
    $mlid = $menu_item['link']['mlid'];
    // Check to see if it is a visible menu item.
    if ($menu_item['link']['hidden'] == 0) {
      // Build class name based on menu path 
      // e.g. to give each menu item individual style.
      // Strip funny symbols.
      $clean_path = str_replace(array('http://', '<', '>', '&', '=', '?', ':'), '', $menu_item['link']['href']);
      // Convert slashes to dashes.
      $clean_path = str_replace('/', '-', $clean_path);
      $path_class = 'menu-path-'. $clean_path;
      // If it has children build a nice little tree under it.
      if ((!empty($menu_item['link']['has_children'])) && (!empty($menu_item['below']))) {
        // Keep passing children into the function 'til we get them all.
        $children = theme('nice_menu_build', $menu_item['below']);
        // Set the class to parent only of children are displayed.
        $parent_class = $children ? 'menuparent ' : '';
        $output .= '<li>'. theme('menu_item_link', $menu_item['link']);       
        // Build the child UL only if children are displayed for the user.
        if ($children) {
          $output .= '<ul>';
          $output .= $children;                     
          $output .= "</ul>\n";
        }
        $output .= "</li>\n";
      }
      else {
        $output .= '<li>'. theme('menu_item_link', $menu_item['link']) .'</li>'."\n";
      }
    }
  }
  return $output;
}

/**
 * Build nice_menu
 */
function phptemplate_nice_menu($id, $menu_name, $mlid, $direction = 'right', $menu = NULL) {
  $output = array();

  if ($menu_tree = theme('nice_menu_tree', $menu_name, $mlid, $menu)) {
    if ($menu_tree['content']) {
      $output['content'] = '<ul>'. $menu_tree['content'] .'</ul>'."\n";
      $output['subject'] = $menu_tree['subject'];
    }
  }
  return $output;
}

/**
 * hook _preprocess_page
 * Generate / override exsisting variables
 */
function phptemplate_preprocess_page(&$vars) {
  $vars['topmenu']         = ubuntudrupal_whichmenu($vars['primary_links']);
  $vars['logo']            = ubuntudrupal_buildlogo($vars);
  $vars['spacergif']       = ubuntudrupal_spacergif();
  $vars['site_name']       = ubuntudrupal_sitename($vars['site_name']);
  $vars['site_slogan']     = ubuntudrupal_siteslogan($vars['site_slogan']);
  $vars['secondary_links'] = ubuntudrupal_secondarylinks($vars['secondary_links']);
  $vars['rulebar']         = ubuntudrupal_rulebar();
  $vars['leftfooter']      = ubuntudrupal_lfooter($vars['footer_message']);
  $vars['rightfooter']     = theme_get_setting('custom_footer_right');
  $vars['center']          = center($vars);
}

/*
 * 3. UbuntuDrupal Functions
 */

/*
 * 3a. UbuntuDrupal Variable Overrides
 */

/**
 * Automatically use the nice_menu module if available
 * If not available, no drop downs will be displayed
 */
function ubuntudrupal_whichmenu($primary_links) {
  if (module_exists('nice_menus')) {
    // Nice Menu
    $usemenu = theme('nice_menu_primary_links');
  }    
  else {
    // Standard Menu
    $usemenu = theme('links', $primary_links, array('class' => ''));
  }
  return $usemenu;
}

/**
 * Generate a logo if the variable exists
 */
function ubuntudrupal_buildlogo($vars) {
  if ($vars[logo]) {
    $logo = '<h1><a href="'. check_url($vars[front_page]) .'" title="'. $vars[site_title] .'">';
    $logo .= '<img src="'. check_url($vars[logo]) .'" alt="'. $vars[site_title] .'" id="ubuntulogo" /></a></h1>';
  }
  if (isset($logo)) {
    return $logo;
  }
}

/**
 * Generate code for a spacer gif
 */
function ubuntudrupal_spacergif() {
  return '<img src="' . base_path() . path_to_theme() . '/images/layout/spacer.gif" width="1" height="1" alt="" />';
}

/**
 * Generate the site name div if the variable exists
 */
function ubuntudrupal_sitename($site_name) {
  if ($site_name) {
    $name = '<div id="logotext"><h1>' . $site_name . '</h1></div>';
  }
  if (isset($name)) {
    return $name;
  }
}

/**
 * Generate the slogan div if the variable exists
 */
function ubuntudrupal_siteslogan($site_slogan) {
  if ($site_slogan) {
    $slogan = '<div id="slogantext"><p>' . $site_slogan . '</p></div>';
  }
  if (isset($slogan)) {
    return $slogan;
  }
}

/**
 * Generate the secondary links if they exist
 */
function ubuntudrupal_secondarylinks($secondary_links) {
  // Disable secondary links if the alternate masthead is enabled
  if (!theme_get_setting('masthead_enabled', FALSE)) {
    if ($secondary_links) {
      return '<div id="sisternav">' . phptemplate_secondary_links($secondary_links) . '</div>';
    }
  }
}

/**
 * Generate code for a simple rule bar
 */
function ubuntudrupal_rulebar() {
  return '<img src="' . base_path() . path_to_theme() . '/images/layout/rulebar.png" width="' . pagewidth(34) . '" height="1" alt="" class="rule" />';
}

/**
 * Generate a left footer or use the default if one has not been set
 */
function ubuntudrupal_lfooter($footmsg) {
  $footmsg = trim($footmsg);
  if ($footmsg == "") {
    $footmsg = '&copy; 2007 Canonical Ltd. Ubuntu and Canonical are registered trademarks of Canonical Ltd.';
  }
  return $footmsg;
}

/*
 * 3b. UbuntuDrupal Functional Variables
 */

/**
 * Generate the center column content
 * Inlcudes the title, tabs, messages, help, content
 */
function center($vars) {
  $tabs2 = menu_secondary_local_tasks();
  $submitted = phptemplate_node_submitted($vars['node']);

  // Display info only on certain node types.
  if (theme_get_setting('toggle_node_info_'. $vars['node']->type)) {
    $submitter = theme('node_submitted', $vars['node']);
  }

  if ($vars[title]) {
    $center .= '<div id="node-title" style="margin-top: 3px;"><div class="inner"><span class="corners-top"><span></span></span>';
  }
  if ($vars['tabs']) { 
    $center .= '<div id="tabs-wrapper" class="clear-block">';
  }
  if (!$vars['tabs'] && $vars['node']->nid) {
    $center .= '<div id="tabs-wrapper" class="clear-block">';
  }
  if ($vars['title']) {
    $center .='<h2'. ($vars['tabs'] ? ' class="with-tabs"' : '') .'>'. $vars['title'] .'</h2>';
  }
  if ($vars['tabs']) {
    $center .= '<ul class="tabs primary">'. $vars['tabs'] .'</ul></div>';
  }
  if ($vars['title'] && !$vars['tabs'] && $vars['node']->nid) {
    $center .= '</div>';
  }
  if ($vars['tabs2']) {
    $center .= '<ul class="tabs secondary">'. $vars['tabs2'] .'</ul>';
  }
  if ($vars['show_messages'] && $vars['messages']) {
    $center .= $vars['messages'];
  }
  if ($submitter) {
    $center .= '<span class="submitted">' . $submitter . '</span>';
  }
  if ($vars['title']) {
    $center .= '<span class="corners-bottom"><span></span></span></div></div>';
  }
  $center .= $vars['help'];
  $center .= $vars['content'];

  return $center;
}

/**
 * Code to handle things needing a static width
 */
function pagewidth($subtract = 0) {
  return theme_get_setting('wrapper_width', 960) - $subtract;
}
